@@ -9,13 +9,18 @@ import traceback
 import shutil
 
 import akerbp.mlops.model_manager as mm
-from akerbp.mlops.deployment import helpers
+from akerbp.mlops.deployment import helpers, platforms
 from akerbp.mlops.core import logger, config
 logging=logger.get_logger(name='mlops_deployment')
-locals().update(config.getenv)
+env = config.envs.env
+service_name = config.envs.service_name
 
 
-def deploy_model(model_settings):
+
+platform_methods = platforms.get_methods()
+
+
+def deploy_model(model_settings, platform_methods=platform_methods):
 
     c = model_settings
     logging.debug(" ")
@@ -25,12 +30,10 @@ def deploy_model(model_settings):
     function_name=f"{c.model_name}-{service_name}-{env}"
 
     if service_name == 'prediction':
-        model_id = mm.set_up_model_artifact(
-            c.model_artifact_folder, 
+        c.model_id = mm.set_up_model_artifact(
+            c.artifact_folder, 
             c.model_name
         )
-    else:
-        model_id = None
 
     m = "Create deployment folder and move required files/folders"
     logging.info(m)
@@ -40,24 +43,10 @@ def deploy_model(model_settings):
 
     logging.debug(f"cd {deployment_folder}")
     os.chdir(deployment_folder)
-
-    logging.info("Write service settings file")
-    mlops_settings=dict(
-        model_name=c.model_name,
-        model_artifact_folder=c.model_artifact_folder,
-        model_import_path=c.model_import_path,
-        model_code_folder=c.model_code_folder,
-        model_id=model_id,
-        test_import_path=c.test_import_path
-    )
-    # File name can't be mlops_settings.py, or there will be an
-    # importing error when the service test is run (user settings <-
-    # model test <- service test)
-    with open('service_settings.py', 'w') as config_file:
-        config_file.write(f'{mlops_settings=}')
     
-    helpers.set_up_requirements(c.model_req_file)
-    c.post_model_reqs()
+    helpers.set_up_requirements(c)
+
+    config.store_service_settings(c)
 
     # * Dependencies: (user settings <- model test). Either run before
     #   going to the dep. folder or copy project config to dep. folder. 
@@ -65,33 +54,35 @@ def deploy_model(model_settings):
     #   folder in case it's used to test prediction service.
     # * Tests need the model requirements installed!
     logging.info(f"Run model and service tests")
-    if c.model_test_file:
-        helpers.run_tests(c.model_test_file)
+    input, check = helpers.get_model_test_data(c.test_import_path)
+    if c.test_file:
+        helpers.run_tests(c.test_file)
         from akerbp.mlops.services.test_service import test_service
-        test_service(c.model_name)
+        test_service(input, check)
     else:
         logging.warning("Model test file is missing! Didn't run tests")
 
 
-    logging.info(f"Deploy {function_name} to {c.deployment_platform}")
-    c.deploy_function(function_name, info=c.info[service_name])
+    logging.info(f"Deploy {function_name} to {c.platform}")
+    deploy_function, test_function = platform_methods[c.platform]
+    deploy_function(function_name, info=c.info[service_name])
     
     if c.test_import_path:
         logging.info("Make a test call")
-        c.test_function(function_name, c.input)
+        test_function(function_name, input)
     else:
         logging.warning("No test file was set up. End-to-end test skipped!")
 
 
-def deploy():
+def deploy(project_settings):
     failed_models = {}
     base_path = os.getcwd()
-    
-    for model_settings in config.project_settings.model_settings:
-        model_name = model_settings.model_name
+        
+    for c in project_settings:
+        model_name = c.model_name
         deployment_folder =f'mlops_{model_name}'
         try:
-            deploy_model(model_settings)
+            deploy_model(c)
         except Exception:
             trace = traceback.format_exc()
             error_message = f"Model failed to deploy!\n{trace}"
@@ -114,4 +105,5 @@ def deploy():
 
 if __name__ == '__main__':
     mm.setup()
-    deploy()
\ No newline at end of file
+    s = config.read_config().project_settings
+    deploy(s)
\ No newline at end of file
